package com.muyu.common.core.web.page;

import com.baomidou.mybatisplus.core.metadata.OrderItem;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Arrays;
import java.util.List;

@Data
@AllArgsConstructor
@NoArgsConstructor
public class QueryModel<T> {
    /**
     * 当前记录起始索引
     */
    private Integer pageNum;
    /**
     * 每页显示记录数
     */
    private Integer pageSize;
    /**
     * 排序列
     */
    private String orderByColumn;
    /**
     * 排序的方向desc或者asc
     */
    private Boolean isAsc = true;
    /**
     * 分页参数合理化
     */
    private Boolean reasonable = true;

    /**
     * 构建模型分页对象
     * @param pageDomain
     * @return
     */
    public T domainBuild(PageDomain pageDomain) {
        this.pageNum = pageDomain.getPageNum();
        this.pageSize = pageDomain.getPageSize();
        this.orderByColumn = pageDomain.getOrderByColumn();
        this.isAsc = "asc".equals(pageDomain.getIsAsc());
        return (T) this;
    }

    /**
     * 构建查询分页对象
     * @return 查询分页对象
     */
    public <I> Page<I> buildPage(){
        Page<I> page = Page.of(this.getPageNum(),this.getPageSize());
        page.setOrders(List.of(this.isAsc()
                ? OrderItem.asc(this.getOrderByColumn()) : OrderItem.desc(this.getOrderByColumn())));
        return page;
    }

    private boolean isAsc() {
        return false;
    }
}
