package com.muyu.controller;
import com.github.pagehelper.Page;
import com.muyu.active.domain.model.ActivityTeamInfoAddModel;
import com.muyu.active.domain.model.ActivityTeamInfoListModel;
import com.muyu.active.domain.model.ActivityTeamInfoUpdModel;
import com.muyu.active.domain.req.ActivityTeamInfoReq;
import com.muyu.active.domain.req.ActivityTeamInfoSaveReq;
import com.muyu.active.domain.req.ActivityTeamInfoUpdReq;
import com.muyu.active.domain.resp.ActivityTeamInfoResp;
import com.muyu.active.domain.resp.TeamInfoFindByIdResp;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.PageUtils;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.service.ActivityTeamInfoService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;


/**
 * 商品拼团信息Controller
 */
@RestController
@RequestMapping("/marketing")
@Slf4j
public class ActivityTeamInfoController {
    @Resource
    private ActivityTeamInfoService activityTeamInfoService;

    //检查前端404的打印
    public ActivityTeamInfoController() {
        log.info("商品拼团控制层{}",getClass().getName());
    }

    /**
     * 列表
     */
    @PostMapping("/list")
    public Result<TableDataInfo<ActivityTeamInfoResp>> list(@RequestBody ActivityTeamInfoReq activityTeamInfoReq) {
//        TableDataInfo<ActivityTeamInfoListModel> list = activityTeamInfoService.list(activityTeamInfoReq.buildModel());
//        List<ActivityTeamInfoListModel> rows = list.getRows();
//        List<ActivityTeamInfoResp> activityTeamInfoResps = rows.stream().map(activityTeamInfoListModel -> {
//            ActivityTeamInfoResp build = ActivityTeamInfoResp.respBuild(activityTeamInfoListModel);
//            return build;
//        }).toList();
//        TableDataInfo<ActivityTeamInfoResp> activityTeamInfoRespTableDataInfo = new TableDataInfo<>();
//        activityTeamInfoRespTableDataInfo.setRows(activityTeamInfoResps);
//        activityTeamInfoRespTableDataInfo.setTotal(list.getTotal());
//        return Result.success(activityTeamInfoRespTableDataInfo);
//         //开始分页
//        PageUtils.startPage(activityTeamInfoReq.getPageNum(),activityTeamInfoReq.getPageSize());
//        // 获取数据列表
//        List<ActivityTeamInfoListModel> row = activityTeamInfoService.list(activityTeamInfoReq.buildModel()).getRows();
//        // 将数据模型转换为响应模型
//        List<ActivityTeamInfoResp> activityTeamInfoResp = row.stream().map(activityTeamInfoListModel -> {
//            return ActivityTeamInfoResp.respBuild(activityTeamInfoListModel);
//        }).toList();
//      // 创建分页信息对象
//      TableDataInfo<ActivityTeamInfoResp> activityTeamInfoRespTableDataInfo= new TableDataInfo<>();
//      activityTeamInfoRespTableDataInfo.setRows(activityTeamInfoResps);
//      activityTeamInfoRespTableDataInfo.setTotal(PageUtils.startPage(activityTeamInfoReq.getPageNum(),activityTeamInfoReq.getPageSize()).getTotal());
//      // 返回结果
//      return Result.success(activityTeamInfoRespTableDataInfo);
        // 开始分页
        Page<ActivityTeamInfoListModel> page = PageUtils.startPage(activityTeamInfoReq.getPageNum(), activityTeamInfoReq.getPageSize());
        // 获取数据列表   列表数据
        List<ActivityTeamInfoListModel> rows = activityTeamInfoService.list(activityTeamInfoReq.buildModel()).getRows();
        // 将数据模型转换为响应模型  利用Steam流吧数据转换为响应列表  起名activityTeamInfoListModel，返回实体类响应调用模型里面的数据，把自定义的实体类放在里面进行相应
        List<ActivityTeamInfoResp> activityTeamInfoResps = rows.stream().map(activityTeamInfoListModel -> {
            return ActivityTeamInfoResp.respBuild(activityTeamInfoListModel);
        }).toList();
        // 创建分页信息对象
        TableDataInfo<ActivityTeamInfoResp> activityTeamInfoRespTableDataInfo = new TableDataInfo<>();
        //列表数据
        activityTeamInfoRespTableDataInfo.setRows(activityTeamInfoResps);
        //条数
        activityTeamInfoRespTableDataInfo.setTotal(page.getTotal());
        // 返回结果
        return Result.success(activityTeamInfoRespTableDataInfo);
    }

    /**
     * 添加
     */
    @PostMapping("/addTeam")
    public Result addTeam(@Valid @RequestBody ActivityTeamInfoSaveReq activityTeamInfoSaveReq){
        //判断是否添加成功所以定义为Boolean类型
        boolean success = activityTeamInfoService.addTeam(activityTeamInfoSaveReq.saveModel());
        //判断添加是否成功
        if (success){
            return Result.success("添加成功");
        }
        return Result.error("添加失败");
    }
    /**
     * 添加团购活动
     * @param activityTeamInfoSaveReq 添加请求对象
     * @return 结果集
     */
    @PostMapping
    public Result<String> save(@RequestBody ActivityTeamInfoSaveReq activityTeamInfoSaveReq) {
        activityTeamInfoService.save(ActivityTeamInfoAddModel.addReqBuild(activityTeamInfoSaveReq));
        return Result.success();
    }

    /**
     * 根据Id查询商品详情信息
     * @param id
     */
    @GetMapping("/findById/{id}")
    public Result<TeamInfoFindByIdResp> findTeamById(@PathVariable Long id){
        return Result.success(TeamInfoFindByIdResp.teamInfoFindByIdBuild(activityTeamInfoService.findDetailById(id)));
    }

    /**
     * 修改拼团活动信息
     * @param activityTeamInfoUpdReq
     */
    @PutMapping("/updateActivityTeamInfo")
    public Result<?> updateByTeamId(@RequestBody ActivityTeamInfoUpdReq activityTeamInfoUpdReq){
        activityTeamInfoService.update(ActivityTeamInfoUpdModel.activityTeamInfoUpdReqModelBuild(activityTeamInfoUpdReq));
        return Result.success();
    }
}
